From 1dc48e943cc9eec02f2d0ebb1dd917c58b3874f6 Mon Sep 17 00:00:00 2001
From: Gustav Bylund <maistho@gmail.com>
Date: Sat, 23 Jun 2018 17:14:03 +0200
Subject: [PATCH] docs(pro): add types for return values in deploy (#2292)

---
 src/@ionic-native/plugins/pro/index.ts | 18 ++++++++++--------
 1 file changed, 10 insertions(+), 8 deletions(-)

diff --git a/src/@ionic-native/plugins/pro/index.ts b/src/@ionic-native/plugins/pro/index.ts
index f11477798..fca81da79 100644
--- a/src/@ionic-native/plugins/pro/index.ts
+++ b/src/@ionic-native/plugins/pro/index.ts
@@ -31,6 +31,8 @@ export interface DeployConfig {
   channel?: string;
 }
 
+export type ProgressMessage = number | string;
+
 /**
  * @hidden
  */
@@ -43,7 +45,7 @@ export class ProDeploy {
    * @param config A valid Deploy config object
    */
   @CordovaInstance()
-  init(config: DeployConfig): Promise<any> { return; }
+  init(config: DeployConfig): Promise<void> { return; }
 
   /**
    * Check a channel for an available update
@@ -54,27 +56,27 @@ export class ProDeploy {
 
   /**
    * Download an available version
    * @return {Observable<any>} Updates with percent completion, or errors with a message.
    */
   @CordovaInstance({
     observable: true
   })
-  download(): Observable<any> { return; }
+  download(): Observable<ProgressMessage> { return; }
 
   /**
    * Unzip the latest downloaded version
    * @return {Observable<any>} Updates with percent completion, or errors with a message.
    */
   @CordovaInstance({
     observable: true
   })
-  extract(): Observable<any> { return; }
+  extract(): Observable<ProgressMessage> { return; }
 
   /**
    * Reload app with the deployed version
    */
   @CordovaInstance()
-  redirect(): Promise<any> { return; }
+  redirect(): Promise<void> { return; }
 
   /**
    * Get info about the version running on the device
@@ -87,14 +89,14 @@ export class ProDeploy {
    * List versions stored on the device
    */
   @CordovaInstance()
-  getVersions(): Promise<any> { return; }
+  getVersions(): Promise<string[]> { return; }
 
   /**
    * Delete a version stored on the device by UUID
    * @param version A version UUID
    */
   @CordovaInstance()
-  deleteVersion(version: string): Promise<any> { return; }
+  deleteVersion(version: string): Promise<void> { return; }
 }
 
 /**
@@ -54,27 +56,27 @@ export class ProDeploy {
   /**
    * Download an available version
-   * @return {Observable<any>} Updates with percent completion, or errors with a message.
+   * @return {Observable<ProgressMessage>} Updates with percent completion, or errors with a message.
    */
   @CordovaInstance({
@@ -54,27 +56,27 @@ export class ProDeploy {
   /**
    * Unzip the latest downloaded version
-   * @return {Observable<any>} Updates with percent completion, or errors with a message.
+   * @return {Observable<ProgressMessage>} Updates with percent completion, or errors with a message.
    */
   @CordovaInstance({